@@ -5,12 +5,27 @@
   Copyright 2008      Y Giridhar Appaji Nag
   Copyright 2008-2009 Philipp Hagemeister
   Copyright 2015-2016 Joao Eriberto Mota Filho
+  Copyright 2016      Stephen Thirlwall
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.
 
+  In addition, as a special exception, the copyright holders give
+  permission to link the code of portions of this program with the
+  OpenSSL library under certain conditions as described in each
+  individual source file, and distribute linked combinations including
+  the two.
+
+  You must obey the GNU General Public License in all respects for all
+  of the code used other than OpenSSL. If you modify file(s) with this
+  exception, you may extend this exception to your version of the
+  file(s), but you are not obligated to do so. If you do not wish to do
+  so, delete this exception statement from your version. If you delete
+  this exception statement from all source files in the program, then
+  also delete it here.
+
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -52,6 +67,7 @@
 #include <arpa/inet.h>
 #include <net/if.h>
 #include <pthread.h>
+#include <openssl/ssl.h>
 
 /* Internationalization */
 #define PACKAGE			"axel"
@@ -63,7 +79,7 @@
 #define MAX_STRING		1024
 #define MAX_ADD_HEADERS	10
 #define MAX_REDIR		5
-#define AXEL_VERSION_STRING	"2.7"
+#define AXEL_VERSION_STRING	"2.11"
 #define DEFAULT_USER_AGENT	"Axel " AXEL_VERSION_STRING " (" ARCH ")"
 
 typedef struct
@@ -80,6 +96,7 @@ typedef message_t if_t;
 #include "ftp.h"
 #include "http.h"
 #include "conn.h"
+#include "ssl.h"
 #include "search.h"
 
 #define min( a, b )		( (a) < (b) ? (a) : (b) )
